package X3D::FieldTypes::MFDouble;

our $VERSION = '0.009';

use X3D::Package 'MFDouble : X3DArrayField { [] }';

1;
__END__
